package ru.ulstu.extractor.ts;

import ru.ulstu.extractor.model.TimeSeriesValue;
import ru.ulstu.extractor.service.TimeSeriesService;

import java.util.List;
import java.util.Map;

import static ru.ulstu.extractor.ts.TimeSeriesDateMapper.mapTimeSeriesToInterval;

public abstract class AbstractTimeSeriesCreator {

    public abstract String getTimeSeriesName();

    /**
     * Извлечь список точек временных рядов
     *
     * @param repositoryId
     * @param branchName
     * @return
     */
    public abstract Map<String, List<TimeSeriesValue>> getTimeSeriesValues(Integer repositoryId, String branchName);

    public abstract TimeSeriesService getTimeSeriesService();

    /**
     * Сохранить извлеченные временные ряды
     *
     * @param repositoryId
     * @param branchName
     */
    public void addTimeSeries(Integer repositoryId, String branchName) {
        // извлеченные точки временных рядов
        Map<String, List<TimeSeriesValue>> timeSeriesValues = getTimeSeriesValues(repositoryId, branchName);

        // сгруппированные по временным интервалам точки временных рядов
        timeSeriesValues.replaceAll((k, v) -> mapTimeSeriesToInterval(getTimeSeriesService().getTimeSeriesInterval(), v));
        getTimeSeriesService().save(timeSeriesValues);
    }
}
