package ru.ulstu.extractor.ts;

import org.springframework.stereotype.Component;
import ru.ulstu.extractor.commit.service.CommitService;
import ru.ulstu.extractor.model.TimeSeriesValue;
import ru.ulstu.extractor.service.TimeSeriesService;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

@Component
public class CommitsTS extends AbstractTimeSeriesCreator {
    private final TimeSeriesService timeSeriesService;
    private final CommitService commitService;

    public CommitsTS(TimeSeriesService timeSeriesService,
                     CommitService commitService) {
        this.timeSeriesService = timeSeriesService;
        this.commitService = commitService;
    }

    @Override
    public String getTimeSeriesName() {
        return "Количество коммитов во времени";
    }

    @Override
    public Map<String, List<TimeSeriesValue>> getTimeSeriesValues(Integer repositoryId, String branchName) {
        //TODO: добавить постраничное чтение
        Map<String, List<TimeSeriesValue>> result = new HashMap<>();
        result.put(String.format("%s %s %s", getTimeSeriesName(), repositoryId, branchName),
                commitService.findByRepositoryIdAndName(repositoryId, branchName)
                        .stream()
                        .map(c -> new TimeSeriesValue(c.getDate(), 1.0))
                        .collect(Collectors.toList()));
        return result;
    }

    @Override
    public TimeSeriesService getTimeSeriesService() {
        return timeSeriesService;
    }
}
